﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;
using Microsoft.AspNetCore.Mvc;
using Benday.AspNetCore.SecuritySample.WebUi.Data;
using Benday.AspNetCore.SecuritySample.WebUi.Models;
using System.Net;
using Microsoft.AspNetCore.Authorization;

namespace Benday.AspNetCore.SecuritySample.WebUi.Controllers
{
    public class LibraryEntryController : Controller
    {
        private ApplicationDbContext _Context;

        public LibraryEntryController(ApplicationDbContext context)
        {
            if (context == null)
            {
                throw new ArgumentNullException(nameof(context), $"{nameof(context)} is null.");
            }

            _Context = context;
        }

        // GET: LibraryEntry
        public ActionResult Index()
        {
            var utility = new SecurityUtility(User.Identity, User);

            var allEntries = _Context.LibraryEntries.ToList();

            var removeThese = new List<LibraryEntry>();

            if (utility.IsAuthorized(SecurityConstants.RoleName_Admin) == false)
            {
                foreach (var item in allEntries)
                {
                    if (utility.IsAuthorized(SecurityConstants.PermissionName_View, item.Id) == false)
                    {
                        removeThese.Add(item);
                    }
                }

                foreach (var item in removeThese)
                {
                    allEntries.Remove(item);
                }
            }

            return View(allEntries);
        }

        private void DebugPrincipal()
        {
            var temp = User.Identity;

            Console.WriteLine();
        }

        // GET: LibraryEntry/Details/5
        // [Authorize(Policy = "ViewLibraryEntryPolicy")]
        public ActionResult Details(int? id)
        {
            if (id == null)
            {
                return BadRequest();
            }

            LibraryEntry libraryEntry = _Context.LibraryEntries.Find(id);

            if (libraryEntry == null)
            {
                return NotFound();
            }

            return View(libraryEntry);
        }

        // GET: LibraryEntry/Create
        public ActionResult Create()
        {
            return View();
        }

        [HttpPost]
        [ValidateAntiForgeryToken]
        public ActionResult Create(LibraryEntry libraryEntry)
        {
            if (ModelState.IsValid)
            {
                _Context.LibraryEntries.Add(libraryEntry);
                _Context.SaveChanges();
                return RedirectToAction("Index");
            }

            return View(libraryEntry);
        }

        // GET: LibraryEntry/Edit/5
        // [Authorize(Policy = "EditLibraryEntryPolicy")]
        public ActionResult Edit(int? id)
        {
            if (id == null)
            {
                return BadRequest();
            }

            var utility = new SecurityUtility(User.Identity, User);

            if (utility.IsAuthorized(SecurityConstants.PermissionName_Edit, id.Value) == false)
            {
                return Forbid();
            }

            LibraryEntry libraryEntry = _Context.LibraryEntries.Find(id);
            if (libraryEntry == null)
            {
                return NotFound();
            }

            return View(libraryEntry);
        }

        [HttpPost]
        [ValidateAntiForgeryToken]
        public ActionResult Edit(LibraryEntry libraryEntry)
        {
            if (ModelState.IsValid)
            {
                var utility = new SecurityUtility(User.Identity, User);

                if (utility.IsAuthorized(SecurityConstants.PermissionName_Edit, libraryEntry.Id) == false)
                {
                    return new ForbidResult();
                }

                _Context.Entry(libraryEntry).State = 
                    Microsoft.EntityFrameworkCore.EntityState.Modified;

                _Context.SaveChanges();

                return RedirectToAction("Index");

            }

            return View(libraryEntry);
        }

        // GET: LibraryEntry/Delete/5

        // [Authorize(Policy = "DeleteLibraryEntryPolicy")]
        public ActionResult Delete(int? id)
        {
            if (id == null)
            {
                return BadRequest();
            }

            var utility = new SecurityUtility(User.Identity, User);

            if (utility.IsAuthorized(SecurityConstants.PermissionName_Edit, id.Value) == false)
            {
                return Forbid();
            }

            LibraryEntry libraryEntry = _Context.LibraryEntries.Find(id);
            if (libraryEntry == null)
            {
                return NotFound();
            }
            return View(libraryEntry);
        }

        // POST: LibraryEntry/Delete/5
        [HttpPost, ActionName("Delete")]
        [ValidateAntiForgeryToken]
        public ActionResult DeleteConfirmed(int id)
        {
            LibraryEntry libraryEntry = _Context.LibraryEntries.Find(id);
            _Context.LibraryEntries.Remove(libraryEntry);
            _Context.SaveChanges();
            return RedirectToAction("Index");
        }

        protected override void Dispose(bool disposing)
        {
            if (disposing)
            {
                _Context.Dispose();
            }
            base.Dispose(disposing);
        }
    }
}