﻿using Microsoft.AspNetCore.Authorization;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;

namespace Benday.AspNetCore.SecuritySample.WebUi.Security
{
    public class AwesomenessHandler : AuthorizationHandler<AwesomenessRequirement>
    {
        protected override Task HandleRequirementAsync(
            AuthorizationHandlerContext context,
            AwesomenessRequirement requirement)
        {
            var awesomenessClaim = 
                context.User.Claims.Where(
                    x => x.Type == SecurityConstants.Claim_LevelOfAwesomeness
                    ).FirstOrDefault();

            if (awesomenessClaim == null)
            {
                context.Fail();
            }
            else
            {
                int awesomenessLevel = Convert.ToInt32(awesomenessClaim.Value);

                if (awesomenessLevel >= requirement.MinimumLevelOfAwesomeness)
                {
                    context.Succeed(requirement);
                }
                else
                {
                    context.Fail();
                }
            }

            return Task.CompletedTask;
        }
    }
}
