using System;

namespace Benday.RightsBasedSecurity.Core.Migrations
{
    using AspNetSecurity;
    using System;
    using System.Data.Entity;
    using System.Data.Entity.Migrations;
    using System.Linq;

    internal sealed class Configuration : DbMigrationsConfiguration<Benday.RightsBasedSecurity.Core.SecurityDbContext>
    {
        public Configuration()
        {
            AutomaticMigrationsEnabled = true;
        }

        protected override void Seed(Benday.RightsBasedSecurity.Core.SecurityDbContext context)
        {
            //  This method will be called after migrating to the latest version.

            //  You can use the DbSet<T>.AddOrUpdate() helper extension method 
            //  to avoid creating duplicate seed data. E.g.
            //
            //    context.People.AddOrUpdate(
            //      p => p.FullName,
            //      new Person { FullName = "Andrew Peters" },
            //      new Person { FullName = "Brice Lambson" },
            //      new Person { FullName = "Rowan Miller" }
            //    );
            //

            AddLibraryEntry(context.LibraryEntries,
                "DevOps Skills for Developers with TFS2017",
                new DateTime(2017, 10, 1),
                "Benjamin Day",
                "PLURALSIGHT.DEVOPS2017",
                "https://www.pluralsight.com/courses/devops-skills-developers-visual-studio-tfs-2017");

            AddLibraryEntry(context.LibraryEntries,
                "Scrum Master Skills", 
                new DateTime(2015, 8, 6), 
                "Benjamin Day", 
                "PLURALSIGHT.SMS",
                "http://app.pluralsight.com/courses/scrum-master-skills");

            AddLibraryEntry(context.LibraryEntries,
                "Real World Scrum with TFS2013",
                new DateTime(2014, 11, 10),
                "Benjamin Day",
                "PLURALSIGHT.RWS",
                "http://app.pluralsight.com/courses/real-world-scrum-team-foundation-server-2013");

            AddLibraryEntry(context.LibraryEntries,
                "Load Testing with VS2013",
                new DateTime(2014, 12, 5),
                "Benjamin Day",
                "PLURALSIGHT.LT2013",
                "http://app.pluralsight.com/courses/load-testing-visual-studio-2013");

            AddLibraryEntry(context.LibraryEntries,
                "Angular 2: Getting Started",
                new DateTime(2016, 4, 1),
                "Deborah Kurata",
                "PLURALSIGHT.ANG2",
                "http://app.pluralsight.com/courses/angular-2-getting-started");

            AddLibraryEntry(context.LibraryEntries,
                "C# Best Practices: Improving on the Basics",
                new DateTime(2015, 10, 29),
                "Deborah Kurata",
                "PLURALSIGHT.CSBP",
                "http://app.pluralsight.com/courses/csharp-best-practices-improving-basics");

            AddLibraryEntry(context.LibraryEntries,
                "The Wright Brothers",
                new DateTime(2015, 5, 5),
                "David McCullough",
                "DMCWBROS",
                "PLANES!");

            AddLibraryEntry(context.LibraryEntries,
                "The Bully Pulpit",
                new DateTime(2013, 11, 5),
                "Doris Kearns Goodwin",
                "DKGTBP",
                "Roosevelt, Taft, and journalism");

            AddLibraryEntry(context.LibraryEntries,
                "The Phoenix Project",
                new DateTime(2013, 1, 10),
                "Gene Kim",
                "GKTPP",
                "A story about DevOps.");

            context.SaveChanges();

            AddAspNetSecurityData(context);
        }

        private void AddPermissionToUser(SecurityDbContext context, AspNetUser user, string permission, int onItemId)
        {
            var claim = new AspNetUserClaim()
            {
                UserId = user.Id,
                ClaimType = permission,
                ClaimValue = onItemId.ToString()
            };

            context.AspNetUserClaims.AddOrUpdate(claim);
        }

        private void AddAspNetSecurityData(SecurityDbContext context)
        {
            var roleUser = new AspNetRole()
            {
                Id = SecurityConstants.RoleName_User,
                Name = SecurityConstants.RoleName_User_FriendlyName
            };

            var roleAdmin = new AspNetRole()
            {
                Id = SecurityConstants.RoleName_Admin,
                Name = SecurityConstants.RoleName_Admin_FriendlyName
            };

            // the password is 'Password'
            string passwordHash = "AHgoeBMeN/IGrjw13Sm+dmBtCH20+taH1LREzHU8xPKQuBEW4hCL3qqNnCVfH5qaNg==";
            string securityStamp = "122b6de4-27fa-4280-96ee-9330123e0748";

            var admin = new AspNetUser()
            {
                Id = "admin@test.org",
                Email = "admin@test.org",
                PasswordHash = passwordHash,
                SecurityStamp = securityStamp,
                UserName = "admin@test.org"
            };

            var user1 = new AspNetUser()
            {
                Id = "user1@test.org",
                Email = "user1@test.org",
                PasswordHash = passwordHash,
                SecurityStamp = securityStamp,
                UserName = "user1@test.org"
            };

            var user2 = new AspNetUser()
            {
                Id = "user2@test.org",
                Email = "user2@test.org",
                PasswordHash = passwordHash,
                SecurityStamp = securityStamp,
                UserName = "user2@test.org"
            };

            var adminUserToAdminRole = new AspNetUserRole()
            {
                RoleId = roleAdmin.Id,
                UserId = admin.Id
            };

            context.AspNetRoles.AddOrUpdate(roleUser);
            context.AspNetRoles.AddOrUpdate(roleAdmin);

            context.AspNetUsers.AddOrUpdate(admin);
            context.AspNetUsers.AddOrUpdate(user1);
            context.AspNetUsers.AddOrUpdate(user2);

            context.AspNetUserRoles.AddOrUpdate(adminUserToAdminRole);

            // add user to admin role
            AddUserToRole(context, admin, SecurityConstants.RoleName_Admin);

            var allLibraryEntries = context.LibraryEntries.ToList();

            AddUserToRole(context, user1, SecurityConstants.RoleName_User);

            AddPermissionToUser(context, 
                user1, 
                SecurityConstants.PermissionName_View, 
                allLibraryEntries[0].Id);

            AddPermissionToUser(context,
                user1,
                SecurityConstants.PermissionName_Edit,
                allLibraryEntries[0].Id);

            AddPermissionToUser(context,
                user1,
                SecurityConstants.PermissionName_View,
                allLibraryEntries[1].Id);

            AddPermissionToUser(context,
                user1,
                SecurityConstants.PermissionName_View,
                allLibraryEntries[2].Id);
        }

        private static void AddUserToRole(SecurityDbContext context, AspNetUser user, string roleName)
        {
            context.AspNetUserClaims.AddOrUpdate(new AspNetUserClaim()
            {
                UserId = user.Id,
                ClaimType = System.Security.Claims.ClaimTypes.Role,
                ClaimValue = roleName
            });
        }

        private void AddLibraryEntry(DbSet<LibraryEntry> libraryEntries, 
            string title, 
            DateTime publishDate, 
            string author, 
            string catalogNumber, 
            string summary)
        {
            var temp = new LibraryEntry();

            temp.Title = title;
            temp.PublishDate = publishDate;
            temp.Author = author;
            temp.CatalogNumber = catalogNumber;
            temp.Summary = summary;
            
            libraryEntries.AddOrUpdate(temp);
        }

        private void AddItemType(IDbSet<ItemType> itemTypes, string itemTypeName)
        {
            var temp = new ItemType();

            temp.Name = itemTypeName;

            itemTypes.AddOrUpdate(temp);
        }

        private void AddItemRight(IDbSet<ItemRight> itemRights, string itemType, string permissionName, bool isItemSpecific)
        {
            var temp = new ItemRight();

            temp.IsItemSpecific = isItemSpecific;
            temp.ItemType = itemType;
            temp.Name = permissionName;

            itemRights.AddOrUpdate(temp);
        }

        private void AddUserLogin(IDbSet<UserLogin> userLogins, 
            string username, 
            string password, 
            string firstName, 
            string lastName)
        {
            var temp = new UserLogin();

            temp.FirstName = firstName;
            temp.LastName = lastName;
            temp.Username = username;
            temp.Password = password;

            userLogins.AddOrUpdate(temp);
        }
    }
}
