﻿using System;
using Microsoft.AspNet.Identity;
using Microsoft.AspNet.Identity.Owin;
using Microsoft.Owin;
using Microsoft.Owin.Security.Cookies;
using Microsoft.Owin.Security.Google;
using Owin;
using Benday.RightsBasedSecurity.WebUi.Models;
using System.Linq;
using System.Security.Claims;
using System.Collections.Generic;
using Benday.RightsBasedSecurity.Core;

namespace Benday.RightsBasedSecurity.WebUi
{
    public partial class Startup
    {
        // For more information on configuring authentication, please visit http://go.microsoft.com/fwlink/?LinkId=301864
        public void ConfigureAuth(IAppBuilder app)
        {
            // Configure the db context, user manager and signin manager to use a single instance per request
            app.CreatePerOwinContext(ApplicationDbContext.Create);
            app.CreatePerOwinContext<ApplicationUserManager>(ApplicationUserManager.Create);
            app.CreatePerOwinContext<ApplicationSignInManager>(ApplicationSignInManager.Create);

            // Enable the application to use a cookie to store information for the signed in user
            // and to use a cookie to temporarily store information about a user logging in with a third party login provider
            // Configure the sign in cookie
            app.UseCookieAuthentication(new CookieAuthenticationOptions
            {
                AuthenticationType = DefaultAuthenticationTypes.ApplicationCookie,
                LoginPath = new PathString("/Account/Login"),
                //Provider = new CookieAuthenticationProvider
                //{
                //    // Enables the application to validate the security stamp when the user logs in.
                //    // This is a security feature which is used when you change a password or add an external login to your account.  
                //    OnValidateIdentity = SecurityStampValidator.OnValidateIdentity<ApplicationUserManager, ApplicationUser>(
                //        validateInterval: TimeSpan.FromMinutes(30),
                //        regenerateIdentity: (manager, user) => user.GenerateUserIdentityAsync(manager))
                //}
                Provider = GetMyCookieAuthenticationProvider()
            });            
            app.UseExternalSignInCookie(DefaultAuthenticationTypes.ExternalCookie);

            // Enables the application to temporarily store user information when they are verifying the second factor in the two-factor authentication process.
            app.UseTwoFactorSignInCookie(DefaultAuthenticationTypes.TwoFactorCookie, TimeSpan.FromMinutes(5));

            // Enables the application to remember the second login verification factor such as phone or email.
            // Once you check this option, your second step of verification during the login process will be remembered on the device where you logged in from.
            // This is similar to the RememberMe option when you log in.
            app.UseTwoFactorRememberBrowserCookie(DefaultAuthenticationTypes.TwoFactorRememberBrowserCookie);

            // Uncomment the following lines to enable logging in with third party login providers
            //app.UseMicrosoftAccountAuthentication(
            //    clientId: "",
            //    clientSecret: "");

            //app.UseTwitterAuthentication(
            //   consumerKey: "",
            //   consumerSecret: "");

            //app.UseFacebookAuthentication(
            //   appId: "",
            //   appSecret: "");

            //app.UseGoogleAuthentication(new GoogleOAuth2AuthenticationOptions()
            //{
            //    ClientId = "",
            //    ClientSecret = ""
            //});
        }

        private static CookieAuthenticationProvider GetMyCookieAuthenticationProvider()
        {
            var cookieAuthenticationProvider = new CookieAuthenticationProvider();
            cookieAuthenticationProvider.OnValidateIdentity = async context =>
            {
                // execute default cookie validation function
                var cookieValidatorFunc =
                SecurityStampValidator.OnValidateIdentity<ApplicationUserManager, ApplicationUser>(
                    TimeSpan.FromMinutes(10),
                    (manager, user) =>
                    {
                        var identity = user.GenerateUserIdentityAsync(manager);
                        return identity;
                    });
                await cookieValidatorFunc.Invoke(context);

                // sanity checks
                if (context.Identity == null || !context.Identity.IsAuthenticated)
                {
                    return;
                }


                RefreshLibraryClaims(context);                
            };
            
            return cookieAuthenticationProvider;
        }
        private static void RefreshLibraryClaims(CookieValidateIdentityContext context)
        {
            var removeThese = new List<Claim>();

            foreach (var claim in context.Identity.Claims)
            {
                if (claim.Type != null && claim.Type.StartsWith("Library.") == true)
                {
                    removeThese.Add(claim);
                }
            }

            if (removeThese.Count > 0)
            {
                removeThese.ForEach(x => context.Identity.TryRemoveClaim(x));
            }

            using (var dbContext = new SecurityDbContext())
            {
                var userClaims = dbContext.AspNetUserClaims.Where(
                    x => x.UserId == context.Identity.Name).ToList();

                foreach (var userClaim in userClaims)
                {
                    context.Identity.AddClaim(
                        new Claim(userClaim.ClaimType, userClaim.ClaimValue));
                }
            }
        }
    }
}