﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Linq;
using System.Net;
using System.Web;
using System.Web.Mvc;
using Benday.RightsBasedSecurity.Core;

namespace Benday.RightsBasedSecurity.WebUi.Controllers
{
    public class ItemGroupController : Controller
    {
        private SecurityDbContext db = new SecurityDbContext();

        // GET: ItemGroup
        public ActionResult Index()
        {
            return View(db.ItemGroups.ToList());
        }

        // GET: ItemGroup/Details/5
        public ActionResult Details(int? id)
        {
            if (id == null)
            {
                return new HttpStatusCodeResult(HttpStatusCode.BadRequest);
            }
            ItemGroup itemGroup = db.ItemGroups.Find(id);
            if (itemGroup == null)
            {
                return HttpNotFound();
            }
            return View(itemGroup);
        }

        // GET: ItemGroup/Create
        public ActionResult Create()
        {
            return View();
        }

        // POST: ItemGroup/Create
        // To protect from overposting attacks, please enable the specific properties you want to bind to, for 
        // more details see http://go.microsoft.com/fwlink/?LinkId=317598.
        [HttpPost]
        [ValidateAntiForgeryToken]
        public ActionResult Create([Bind(Include = "Id,Name,ItemType")] ItemGroup itemGroup)
        {
            if (ModelState.IsValid)
            {
                db.ItemGroups.Add(itemGroup);
                db.SaveChanges();
                return RedirectToAction("Index");
            }

            return View(itemGroup);
        }

        // GET: ItemGroup/Edit/5
        public ActionResult Edit(int? id)
        {
            if (id == null)
            {
                return new HttpStatusCodeResult(HttpStatusCode.BadRequest);
            }
            ItemGroup itemGroup = db.ItemGroups.Find(id);
            if (itemGroup == null)
            {
                return HttpNotFound();
            }
            return View(itemGroup);
        }

        // POST: ItemGroup/Edit/5
        // To protect from overposting attacks, please enable the specific properties you want to bind to, for 
        // more details see http://go.microsoft.com/fwlink/?LinkId=317598.
        [HttpPost]
        [ValidateAntiForgeryToken]
        public ActionResult Edit([Bind(Include = "Id,Name,ItemType")] ItemGroup itemGroup)
        {
            if (ModelState.IsValid)
            {
                db.Entry(itemGroup).State = EntityState.Modified;
                db.SaveChanges();
                return RedirectToAction("Index");
            }
            return View(itemGroup);
        }

        // GET: ItemGroup/Delete/5
        public ActionResult Delete(int? id)
        {
            if (id == null)
            {
                return new HttpStatusCodeResult(HttpStatusCode.BadRequest);
            }
            ItemGroup itemGroup = db.ItemGroups.Find(id);
            if (itemGroup == null)
            {
                return HttpNotFound();
            }
            return View(itemGroup);
        }

        // POST: ItemGroup/Delete/5
        [HttpPost, ActionName("Delete")]
        [ValidateAntiForgeryToken]
        public ActionResult DeleteConfirmed(int id)
        {
            ItemGroup itemGroup = db.ItemGroups.Find(id);
            db.ItemGroups.Remove(itemGroup);
            db.SaveChanges();
            return RedirectToAction("Index");
        }

        protected override void Dispose(bool disposing)
        {
            if (disposing)
            {
                db.Dispose();
            }
            base.Dispose(disposing);
        }
    }
}
