﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Linq;
using System.Net;
using System.Web;
using System.Web.Mvc;
using Benday.RightsBasedSecurity.Core;

namespace Benday.RightsBasedSecurity.WebUi.Controllers
{
    public class ItemGroupMemberController : Controller
    {
        private SecurityDbContext db = new SecurityDbContext();

        // GET: ItemGroupMember
        public ActionResult Index()
        {
            return View(db.ItemGroupMembers.ToList());
        }

        // GET: ItemGroupMember/Details/5
        public ActionResult Details(int? id)
        {
            if (id == null)
            {
                return new HttpStatusCodeResult(HttpStatusCode.BadRequest);
            }
            ItemGroupMember itemGroupMember = db.ItemGroupMembers.Find(id);
            if (itemGroupMember == null)
            {
                return HttpNotFound();
            }
            return View(itemGroupMember);
        }

        // GET: ItemGroupMember/Create
        public ActionResult Create()
        {
            return View();
        }

        // POST: ItemGroupMember/Create
        // To protect from overposting attacks, please enable the specific properties you want to bind to, for 
        // more details see http://go.microsoft.com/fwlink/?LinkId=317598.
        [HttpPost]
        [ValidateAntiForgeryToken]
        public ActionResult Create([Bind(Include = "Id,ItemGroupId,ItemId")] ItemGroupMember itemGroupMember)
        {
            if (ModelState.IsValid)
            {
                db.ItemGroupMembers.Add(itemGroupMember);
                db.SaveChanges();
                return RedirectToAction("Index");
            }

            return View(itemGroupMember);
        }

        // GET: ItemGroupMember/Edit/5
        public ActionResult Edit(int? id)
        {
            if (id == null)
            {
                return new HttpStatusCodeResult(HttpStatusCode.BadRequest);
            }
            ItemGroupMember itemGroupMember = db.ItemGroupMembers.Find(id);
            if (itemGroupMember == null)
            {
                return HttpNotFound();
            }
            return View(itemGroupMember);
        }

        // POST: ItemGroupMember/Edit/5
        // To protect from overposting attacks, please enable the specific properties you want to bind to, for 
        // more details see http://go.microsoft.com/fwlink/?LinkId=317598.
        [HttpPost]
        [ValidateAntiForgeryToken]
        public ActionResult Edit([Bind(Include = "Id,ItemGroupId,ItemId")] ItemGroupMember itemGroupMember)
        {
            if (ModelState.IsValid)
            {
                db.Entry(itemGroupMember).State = EntityState.Modified;
                db.SaveChanges();
                return RedirectToAction("Index");
            }
            return View(itemGroupMember);
        }

        // GET: ItemGroupMember/Delete/5
        public ActionResult Delete(int? id)
        {
            if (id == null)
            {
                return new HttpStatusCodeResult(HttpStatusCode.BadRequest);
            }
            ItemGroupMember itemGroupMember = db.ItemGroupMembers.Find(id);
            if (itemGroupMember == null)
            {
                return HttpNotFound();
            }
            return View(itemGroupMember);
        }

        // POST: ItemGroupMember/Delete/5
        [HttpPost, ActionName("Delete")]
        [ValidateAntiForgeryToken]
        public ActionResult DeleteConfirmed(int id)
        {
            ItemGroupMember itemGroupMember = db.ItemGroupMembers.Find(id);
            db.ItemGroupMembers.Remove(itemGroupMember);
            db.SaveChanges();
            return RedirectToAction("Index");
        }

        protected override void Dispose(bool disposing)
        {
            if (disposing)
            {
                db.Dispose();
            }
            base.Dispose(disposing);
        }
    }
}
