﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Linq;
using System.Net;
using System.Web;
using System.Web.Mvc;
using Benday.RightsBasedSecurity.Core;

namespace Benday.RightsBasedSecurity.WebUi.Controllers
{
    public class ItemRightController : Controller
    {
        private SecurityDbContext db = new SecurityDbContext();

        // GET: ItemRight
        public ActionResult Index()
        {
            return View(db.ItemRights.ToList());
        }

        // GET: ItemRight/Details/5
        public ActionResult Details(int? id)
        {
            if (id == null)
            {
                return new HttpStatusCodeResult(HttpStatusCode.BadRequest);
            }
            ItemRight itemRight = db.ItemRights.Find(id);
            if (itemRight == null)
            {
                return HttpNotFound();
            }
            return View(itemRight);
        }

        // GET: ItemRight/Create
        public ActionResult Create()
        {
            return View();
        }

        // POST: ItemRight/Create
        // To protect from overposting attacks, please enable the specific properties you want to bind to, for 
        // more details see http://go.microsoft.com/fwlink/?LinkId=317598.
        [HttpPost]
        [ValidateAntiForgeryToken]
        public ActionResult Create([Bind(Include = "Id,Name,IsItemSpecific,ItemType")] ItemRight itemRight)
        {
            if (ModelState.IsValid)
            {
                db.ItemRights.Add(itemRight);
                db.SaveChanges();
                return RedirectToAction("Index");
            }

            return View(itemRight);
        }

        // GET: ItemRight/Edit/5
        public ActionResult Edit(int? id)
        {
            if (id == null)
            {
                return new HttpStatusCodeResult(HttpStatusCode.BadRequest);
            }
            ItemRight itemRight = db.ItemRights.Find(id);
            if (itemRight == null)
            {
                return HttpNotFound();
            }
            return View(itemRight);
        }

        // POST: ItemRight/Edit/5
        // To protect from overposting attacks, please enable the specific properties you want to bind to, for 
        // more details see http://go.microsoft.com/fwlink/?LinkId=317598.
        [HttpPost]
        [ValidateAntiForgeryToken]
        public ActionResult Edit([Bind(Include = "Id,Name,IsItemSpecific,ItemType")] ItemRight itemRight)
        {
            if (ModelState.IsValid)
            {
                db.Entry(itemRight).State = EntityState.Modified;
                db.SaveChanges();
                return RedirectToAction("Index");
            }
            return View(itemRight);
        }

        // GET: ItemRight/Delete/5
        public ActionResult Delete(int? id)
        {
            if (id == null)
            {
                return new HttpStatusCodeResult(HttpStatusCode.BadRequest);
            }
            ItemRight itemRight = db.ItemRights.Find(id);
            if (itemRight == null)
            {
                return HttpNotFound();
            }
            return View(itemRight);
        }

        // POST: ItemRight/Delete/5
        [HttpPost, ActionName("Delete")]
        [ValidateAntiForgeryToken]
        public ActionResult DeleteConfirmed(int id)
        {
            ItemRight itemRight = db.ItemRights.Find(id);
            db.ItemRights.Remove(itemRight);
            db.SaveChanges();
            return RedirectToAction("Index");
        }

        protected override void Dispose(bool disposing)
        {
            if (disposing)
            {
                db.Dispose();
            }
            base.Dispose(disposing);
        }
    }
}
