﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Linq;
using System.Net;
using System.Web;
using System.Web.Mvc;
using Benday.RightsBasedSecurity.Core;
using System.Threading;

namespace Benday.RightsBasedSecurity.WebUi.Controllers
{
    public class LibraryEntryController : Controller
    {
        private SecurityDbContext db = new SecurityDbContext();

        // GET: LibraryEntry
        public ActionResult Index()
        {
            var utility = new SecurityUtility(User.Identity, User);
            
            var allEntries = db.LibraryEntries.ToList();

            var removeThese = new List<LibraryEntry>();

            if (utility.IsAuthorized(SecurityConstants.RoleName_Admin) == false)
            {
                foreach (var item in allEntries)
                {
                    if (utility.IsAuthorized(SecurityConstants.PermissionName_View, item.Id) == false)
                    {
                        removeThese.Add(item);
                    }
                }

                foreach (var item in removeThese)
                {
                    allEntries.Remove(item);
                }
            }

            return View(allEntries);
        }

        private void DebugPrincipal()
        {
            var temp = User.Identity;

            Console.WriteLine();
        }

        // GET: LibraryEntry/Details/5
        public ActionResult Details(int? id)
        {
            if (id == null)
            {
                return new HttpStatusCodeResult(HttpStatusCode.BadRequest);
            }
            LibraryEntry libraryEntry = db.LibraryEntries.Find(id);
            if (libraryEntry == null)
            {
                return HttpNotFound();
            }
            return View(libraryEntry);
        }

        // GET: LibraryEntry/Create
        public ActionResult Create()
        {
            return View();
        }

        // POST: LibraryEntry/Create
        // To protect from overposting attacks, please enable the specific properties you want to bind to, for 
        // more details see http://go.microsoft.com/fwlink/?LinkId=317598.
        [HttpPost]
        [ValidateAntiForgeryToken]
        public ActionResult Create([Bind(Include = "Id,Title,PublishDate,Author,CatalogNumber,Summary")] LibraryEntry libraryEntry)
        {
            if (ModelState.IsValid)
            {
                db.LibraryEntries.Add(libraryEntry);
                db.SaveChanges();
                return RedirectToAction("Index");
            }

            return View(libraryEntry);
        }

        // GET: LibraryEntry/Edit/5
        public ActionResult Edit(int? id)
        {
            if (id == null)
            {
                return new HttpStatusCodeResult(HttpStatusCode.BadRequest);
            }
            
            var utility = new SecurityUtility(User.Identity, User);

            if (utility.IsAuthorized(SecurityConstants.PermissionName_Edit, id.Value) == false)
            {
                return new HttpStatusCodeResult(HttpStatusCode.Forbidden);
            }
            
            LibraryEntry libraryEntry = db.LibraryEntries.Find(id);
            if (libraryEntry == null)
            {
                return HttpNotFound();
            }

            return View(libraryEntry);
        }

        // POST: LibraryEntry/Edit/5
        // To protect from overposting attacks, please enable the specific properties you want to bind to, for 
        // more details see http://go.microsoft.com/fwlink/?LinkId=317598.
        [HttpPost]
        [ValidateAntiForgeryToken]
        public ActionResult Edit([Bind(Include = "Id,Title,PublishDate,Author,CatalogNumber,Summary")] LibraryEntry libraryEntry)
        {
            if (ModelState.IsValid)
            {
                var utility = new SecurityUtility(User.Identity, User);

                if (utility.IsAuthorized(SecurityConstants.PermissionName_Edit, libraryEntry.Id) == false)
                {
                    return new HttpStatusCodeResult(HttpStatusCode.Forbidden);
                }

                db.Entry(libraryEntry).State = EntityState.Modified;
                db.SaveChanges();
                return RedirectToAction("Index");
            }
            return View(libraryEntry);
        }

        // GET: LibraryEntry/Delete/5
        public ActionResult Delete(int? id)
        {
            if (id == null)
            {
                return new HttpStatusCodeResult(HttpStatusCode.BadRequest);
            }

            var utility = new SecurityUtility(User.Identity, User);

            if (utility.IsAuthorized(SecurityConstants.PermissionName_Edit, id.Value) == false)
            {
                return new HttpStatusCodeResult(HttpStatusCode.Forbidden);
            }

            LibraryEntry libraryEntry = db.LibraryEntries.Find(id);
            if (libraryEntry == null)
            {
                return HttpNotFound();
            }
            return View(libraryEntry);
        }

        // POST: LibraryEntry/Delete/5
        [HttpPost, ActionName("Delete")]
        [ValidateAntiForgeryToken]
        public ActionResult DeleteConfirmed(int id)
        {
            LibraryEntry libraryEntry = db.LibraryEntries.Find(id);
            db.LibraryEntries.Remove(libraryEntry);
            db.SaveChanges();
            return RedirectToAction("Index");
        }

        protected override void Dispose(bool disposing)
        {
            if (disposing)
            {
                db.Dispose();
            }
            base.Dispose(disposing);
        }
    }
}
