﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Linq;
using System.Net;
using System.Web;
using System.Web.Mvc;
using Benday.RightsBasedSecurity.Core;

namespace Benday.RightsBasedSecurity.WebUi.Controllers
{
    public class UserGroupMemberController : Controller
    {
        private SecurityDbContext db = new SecurityDbContext();

        // GET: UserGroupMember
        public ActionResult Index()
        {
            return View(db.UserGroupMembers.ToList());
        }

        // GET: UserGroupMember/Details/5
        public ActionResult Details(int? id)
        {
            if (id == null)
            {
                return new HttpStatusCodeResult(HttpStatusCode.BadRequest);
            }
            UserGroupMember userGroupMember = db.UserGroupMembers.Find(id);
            if (userGroupMember == null)
            {
                return HttpNotFound();
            }
            return View(userGroupMember);
        }

        // GET: UserGroupMember/Create
        public ActionResult Create()
        {
            return View();
        }

        // POST: UserGroupMember/Create
        // To protect from overposting attacks, please enable the specific properties you want to bind to, for 
        // more details see http://go.microsoft.com/fwlink/?LinkId=317598.
        [HttpPost]
        [ValidateAntiForgeryToken]
        public ActionResult Create([Bind(Include = "Id,UserGroupId,UserId")] UserGroupMember userGroupMember)
        {
            if (ModelState.IsValid)
            {
                db.UserGroupMembers.Add(userGroupMember);
                db.SaveChanges();
                return RedirectToAction("Index");
            }

            return View(userGroupMember);
        }

        // GET: UserGroupMember/Edit/5
        public ActionResult Edit(int? id)
        {
            if (id == null)
            {
                return new HttpStatusCodeResult(HttpStatusCode.BadRequest);
            }
            UserGroupMember userGroupMember = db.UserGroupMembers.Find(id);
            if (userGroupMember == null)
            {
                return HttpNotFound();
            }
            return View(userGroupMember);
        }

        // POST: UserGroupMember/Edit/5
        // To protect from overposting attacks, please enable the specific properties you want to bind to, for 
        // more details see http://go.microsoft.com/fwlink/?LinkId=317598.
        [HttpPost]
        [ValidateAntiForgeryToken]
        public ActionResult Edit([Bind(Include = "Id,UserGroupId,UserId")] UserGroupMember userGroupMember)
        {
            if (ModelState.IsValid)
            {
                db.Entry(userGroupMember).State = EntityState.Modified;
                db.SaveChanges();
                return RedirectToAction("Index");
            }
            return View(userGroupMember);
        }

        // GET: UserGroupMember/Delete/5
        public ActionResult Delete(int? id)
        {
            if (id == null)
            {
                return new HttpStatusCodeResult(HttpStatusCode.BadRequest);
            }
            UserGroupMember userGroupMember = db.UserGroupMembers.Find(id);
            if (userGroupMember == null)
            {
                return HttpNotFound();
            }
            return View(userGroupMember);
        }

        // POST: UserGroupMember/Delete/5
        [HttpPost, ActionName("Delete")]
        [ValidateAntiForgeryToken]
        public ActionResult DeleteConfirmed(int id)
        {
            UserGroupMember userGroupMember = db.UserGroupMembers.Find(id);
            db.UserGroupMembers.Remove(userGroupMember);
            db.SaveChanges();
            return RedirectToAction("Index");
        }

        protected override void Dispose(bool disposing)
        {
            if (disposing)
            {
                db.Dispose();
            }
            base.Dispose(disposing);
        }
    }
}
